C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine init_input(
     &                      modfil_L1B_1km,
     &                      modfil_L1B_250m,
     &                      modfil_mod35,
     &                      modfil_Geo,
     &                      buf_size,
     &                      buf_geo_size,
     &                      buf_anc_size,
     &                      qa_bits,
     &                      mask_array,
     &                      qa_array
     &                     )
      implicit none
      save

c----------------------------------------------------------------------
C!F77
c
c!Description:
C     Routine for initializing variables used in the cloud mask
c     MODIS software.
C
c!Input parameters:
c modfil_L1b_1km   Level 1B hdf file array - 1km data
c modfil_L1b_250m  Level 1B hdf file array - 250m data
c modfil_mod35     Output cloud mask file hdf file array
c modfil_Geo       Geolocation file hdf array
c buf_size         Line and element granule size
c buf_geo_size     Line and element geolocation file size
c buf_anc_size     Line and element ancillary data file size
c qa_bits          10 byte array contining qa bit results
c mask_array         Array containing a line of cloud mask bit values
c qa_array      Array containing line of 10 byte qa results
c
c!Output Parameters:
c None.
c
c!Revision History:
c
c!Team-unique Header:
c
c!END
c----------------------------------------------------------------------
      INCLUDE 'global.inc'

c --- parameters
      integer 		modfil_L1B_1km(MODFILLEN)
      integer		modfil_L1B_250m(MODFILLEN)
      integer		modfil_mod35(MODFILLEN)
      integer		modfil_Geo(MODFILLEN)
      integer		buf_size(2)
      integer		buf_geo_size(2)
      integer		buf_anc_size(2)
      byte 		mask_array(NPIXEL,6)
      byte 		qa_array(NPIXEL,10)
      byte 		qa_bits(10)

c --- local variables
      integer		i
      integer		j


c --- initialize the data arries
      do i = 1 , MODFILLEN
      modfil_L1b_1km(i) = 0
      modfil_L1b_250m(i) = 0
      modfil_mod35(i) = 0
      modfil_Geo(i) = 0
      enddo

c --- set max buf size of radiance data
      buf_size(1) = NX
      buf_size(2) = NY

c --- set max buf size of geolocation data
      buf_geo_size(1) = NPIXEL
      buf_geo_size(2) = SCANS_CUBE

c --- set max buf size of ancillary data file
      buf_anc_size(1) = NPIXEL
      buf_anc_size(2) = SCANS_CUBE

c --- initialize testbits and qa_bits output products
c     Initialize array which holds cloud mask bit results for each line
      do i = 1 , NPIXEL
      do j = 1 , 10
      if (j .le. 6) mask_array(i,j) = 0
      qa_array(i,j) = 0
      enddo
      enddo

c --- Initialize qa_bits right away. Will set some in file open routine
      do i = 1 , 10
      qa_bits(i) = 0
      enddo

      return 
      end
