C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine fill_bit_line(nc,nmtests,nbands,bad_value,bad_geo,
     +                         snglnt,desert,testbits,qa_bits,bitarray,
     +                         qa_bitarray)

      implicit none
      save

c----------------------------------------------------------------------
c!F77 
c
c!Description:
c     Routine for placing results of the cloud mask product and
c     qa array into a line of data values.
c
c!Input parameters:
c nc            Current processing element
c nmtests       Number of tests applied to this pixel
c nbands        Number of bands successfully read for this pixel
c bad_value     Logical value indicating band radiance or reflectance 
c               value
c bad_geo       Logical variable flagging bad lat/long data
c snglnt        Logical variables where true indicates sun glint
c desert        Logical varibable whre true indicates desert ecosystem
c testbits      four-byte integer containing bit results
c qa_bits       Byte array containing qa bit results
c
c!Output Parameters:
c bitarray      Array containing line of 48 bit test results
c qa_bitarray   Array containing line of 10 byte qa results
c
c!Revision History:
c
c!Team-unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!END
c----------------------------------------------------------------------

      include 'global.inc'

c     scalar arguments
      integer nc,nmtests,nbands
      logical bad_value,snglnt,desert,bad_geo

c     scalar arrays
      byte testbits(6),bitarray(npixel,6),qa_bits(10),
     +     qa_bitarray(npixel,10) 

c     local scalars 
      logical lval
      integer i,j,debug,h_output,ibyte,ipos,ival,jj,kk

c     local arrays
      integer bits(48),qa(80)

c     external routines
      external set_bit,set_qa_bit

c ... Common statement for debug purposes
      common / bug / debug, h_output

c ... debug statement ............................................
      if (debug .gt. 0) then
        write(h_output,'(10x/,''Within fill_bit_line routine '',/)')
        write(h_output,'(10x/,''Bad_value,Bad_geo, desert, sunglint= '',
     +        4L5,/)') bad_value, bad_geo, desert, snglnt
      endif
c .............................................................

c ... Fill in final pixel values before putting into line
c     array.  This is where the quality of the cloud mask
c     product is determined.  

c ... Now decide quality of pixel confidence based upon
c ...  number of tests used and processing path

c ... Next, how many tests and bands were used? If none
c ... set all output product bits to zero.
      if (nmtests .eq. 0 .or. nbands .eq. 0 .or. bad_geo) then
        do 100 i = 1 , 6
          testbits(i) = 0
  100   continue
c ...   and set the usable qa_bit to 0 (not useful)
        qa_bits(1) = 0

c ... If there were still some bands that were useful,
c ... then scale the qaulity accordingly
c ... (< 3 set quality bit to 4)
      else if (nmtests .lt. 3) then

        call set_bit(testbits,0)  
        call set_qa_bit(qa_bits,0)
        call set_qa_bit(qa_bits,3)

c ... (< 7 set quality bit to 6)
      else if (nmtests .lt. 7) then

        call set_bit(testbits,0)  
        call set_qa_bit(qa_bits,0)
        call set_qa_bit(qa_bits,2)
        call set_qa_bit(qa_bits,3)

c     Else set qaulity to highest value of 7
      else

         call set_bit(testbits,0)
         do i = 0 , 3
           call set_qa_bit(qa_bits,i)
         enddo

      endif

c ... Now if area is in difficult processing path region then
c ...  reduce quality to 6
      if (snglnt) then
         if (qa_bits(1) .eq. 15) qa_bits(1) = 13
      endif

c ... save bit flags for the current element in the line array
      do 200 i = 1 , 10
        if (i .le. 6) bitarray(nc,i) = testbits(i)
        qa_bitarray(nc,i) = qa_bits(i)
  200 continue

c ... debug statement ............................................
      if (debug .gt. 0) then
c        strip out and print bit values for current pixel
         ival = 0
         ipos = 0
         do i = 1 , 48
            bits(i) = 0
         enddo
         do ibyte = 1,6
            ival = bitarray(nc,ibyte)
            do j = 1,8
               ipos = ipos + 1
               lval = btest(ival,j-1)
               if(lval) then
                  bits(ipos) = 1
               else
                  bits(ipos) = 0
              end if
            enddo
         enddo

         write(h_output,'(1x,3x,'' CM Bits Results'')')
         write(h_output,'(1x,3x,''FOV No'',3x,16(i2,2x))')(kk,kk=0,15)
         write(h_output,'(1x)')
         write(h_output,'(1x,i8,2x,16i4)') nc,(bits(jj),jj=1,16)
         write(h_output,'(1x,i8,2x,16i4)') nc,(bits(jj),jj=17,32)
         write(h_output,'(1x,i8,2x,16i4,/)') nc,(bits(jj),jj=33,48)

         ipos = 0
         do i = 1 , 80
            qa(i) = 0
         enddo
         do ibyte = 1,10
            ival = qa_bitarray(nc,ibyte)
            do j = 1,8
               ipos = ipos + 1
               lval = btest(ival,j-1)
               if(lval) then
                  qa(ipos) = 1
               else
                  qa(ipos) = 0
              end if
            enddo
         enddo

         write(h_output,'(1x,3x,'' QA Bits Results'')')
         write(h_output,'(1x,3x,''FOV No'',3x,16(i2,2x))')(kk,kk=0,15)
         write(h_output,'(1x)')
         write(h_output,'(1x,i8,2x,16i4)') nc,(qa(jj),jj=1,16)
         write(h_output,'(1x,i8,2x,16i4)') nc,(qa(jj),jj=17,32)
         write(h_output,'(1x,i8,2x,16i4)') nc,(qa(jj),jj=33,48)
         write(h_output,'(1x,i8,2x,16i4)') nc,(qa(jj),jj=49,64)
         write(h_output,'(1x,i8,2x,16i4,/)') nc,(qa(jj),jj=65,80)

        write(h_output,'(10x,''testbits pixel results'',/,6i5,/,6i5)')
     +        testbits(1),testbits(2),testbits(3),testbits(4),
     +        testbits(5),testbits(6),bitarray(nc,1),bitarray(nc,2),
     +        bitarray(nc,3),bitarray(nc,4),bitarray(nc,5),
     +        bitarray(nc,6)
        write(h_output,'(10x,'' qa_bits pixel results ''/10i5,/10i5)')
     +        qa_bits(1),qa_bits(2),qa_bits(3),qa_bits(4),
     +        qa_bits(5),qa_bits(6),qa_bits(7),qa_bits(8),
     +        qa_bits(9),qa_bits(10),qa_bitarray(nc,1),
     +        qa_bitarray(nc,2),qa_bitarray(nc,3),qa_bitarray(nc,4),
     +        qa_bitarray(nc,5),qa_bitarray(nc,6),qa_bitarray(nc,7),
     +        qa_bitarray(nc,8),qa_bitarray(nc,9),qa_bitarray(nc,10)
      endif
c ................................................................

      return
      end
