C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center,
C  University C  of Wisconsin-Madison, Madison WI.
C
C  This program is free software; you can redistribute it
C  and/or modify it under the terms of the GNU General
C  Public License as published by the Free Software Foundation;
C  either version 2 of the License, or (at your option) any
C  later version.
C
C  This program is distributed in the hope that it will be
C  useful, but WITHOUT ANY WARRANTY; without even the implied
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public
C  License along with this program; if not, write to the Free
C  Software Foundation, Inc., 59 Temple Place, Suite 330,
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine massage_snowice(map_nise,xsize,ysize)

c---------------------------------------------------------------------
c!F77
c
c!Description:
c     Subroutine for filling in snow and ice information in coastal
c     regions.  For all coast pixels in the NISE data, search both
c     latitudinally and longitudinally for non-coast pixels which
c     indicate snow or ice.  Stop search when non-snow/ice, non-coast
c     pixels are found.  For those coast pixels which have snow/ice
c     pixels indicated on their boundaries, set flag to indicate 
c     snow/ice.
c
c!Input Parameters:
c map_nise    Input/output snow/ice data grid
c xsize       Grid size in the horizontal direction
c ysize       Grid size in the vertical direction
c
c!Output Parameters:
c map_nise    Input/output snow/ice data grid
c
c!Revision History:
c Original subroutine:
c     03-09-04  R. Frey
c
c!Team-Unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-06.
c
c!End
c----------------------------------------------------------------------

      implicit none
      save

c     Arguments.
      integer xsize, ysize
      character*1 map_nise(xsize,ysize)

c     Local arrays.
      integer k(4)

c     Local scalars.
      integer temp_nise, i, j, m, n

c     Loop through map data.

      do j = 1, xsize

        do i = 1, ysize

          temp_nise = 0

c         Check for coast pixel (value = 252).

          if( ichar( map_nise(j,i) ) .eq. 252 ) then

c           Check if on map edges.  Cannot search on all four sides.
c           No data in corners.

            if(j .eq. 1) then
              k(1) = ichar(map_nise(j+1,i))
              k(2) = ichar(map_nise(j,i-1))
              k(3) = ichar(map_nise(j,i+1))
              k(4) = 0
         
            else if(i .eq. 1) then
              k(1) = ichar(map_nise(j,i+1))
              k(2) = ichar(map_nise(j+1,i))
              k(3) = ichar(map_nise(j-1,i))
              k(4) = 0

            else if(j .eq. xsize) then
              k(1) = ichar(map_nise(j-1,i))
              k(2) = ichar(map_nise(j,i-1))
              k(3) = ichar(map_nise(j,i+1))
              k(4) = 0
         
            else if(i .eq. ysize) then
              k(1) = ichar(map_nise(j,i-1))
              k(2) = ichar(map_nise(j+1,i))
              k(3) = ichar(map_nise(j-1,i))
              k(4) = 0

            else

c             Get all four adjacent values.
              k(1) = ichar(map_nise(j,i-1))
              k(2) = ichar(map_nise(j,i+1))
              k(3) = ichar(map_nise(j-1,i))
              k(4) = ichar(map_nise(j+1,i))

            end if

c           Fill in missing snow/ice values (=200).
            do m = 1,4

              n = k(m)
              if(n .ne. 0) then

                if((n .eq. 103 .or. n .eq. 104 .or. n .eq. 200) .or. 
     *                             (n .gt. 25 .and. n .lt. 102)) then
                  temp_nise = 200
                end if

              end if
            enddo

            if (temp_nise .eq. 200) map_nise(j,i) = char(temp_nise)

          end if

        enddo

      enddo

      return
      end
