C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine store_cm_scan(nc,confdnc,day,visusd,snglnt,snow,ice,
     *                         coast,desert,land,process,scan_confdnc,
     *                         scan_visusd,scan_snglnt,scan_snow,
     *                         scan_ice,scan_coast,scan_desert,
     *                         scan_land,scan_process,scan_day)

      implicit none
      save

c-----------------------------------------------------------------------
c!F77
c
c!DESCRIPTION:  Routine to save 1-km values for each pixel on current 
c               scan.
c
c!Input Parameters:
c nc            Current pixel number
c confdnc       Clear-sky confidence of current pixel
c day           Logical variable flagging day scenes
c visusd        Logical variable indicating vis. data used
c snglnt        Logical variable flagging sunglint regions
c snow          Logical variable flagging snow processing 
c ice           Logical variable flagging ice processing 
c coast         Logical variable flagging coast processing 
c desert        Logical variable flagging desert processing 
c land          Logical variable flagging land processing 
c process       Logical variable indicating current pixel processed
c
c!Output Parameters:
c scan_confdnc  Clear-sky confidence array for pixels on current scan
c scan_visusd   Indicates vis. data used for pixels on current scan
c scan_snglnt   Indicates sunglint for pixels on current scan
c scan_snow     Indicates snow processing for pixels on current scan
c scan_ice      Indicates ice processing for pixels on current scan
c scan_coast    Indicates coast processing for pixels on current scan
c scan_desert   Indicates desert processing for pixels on current scan
c scan_land     Indicates land processing for pixels on current scan
c scan_process  Indicates pixel processed for pixels on current scan
c scan_day      Indicates day processing for pixels on current scan
c
c!Revision History:
c
c!Team-Unique Header:
c
c!References and Credits:
c See Cloud Mask ATBD-MOD-35.
c
c!END
c---------------------------------------------------------------------

      INCLUDE 'global.inc'

c     Array arguments.
      real confdnc,scan_confdnc(npixel)
      logical scan_day(npixel),scan_visusd(npixel),scan_snglnt(npixel),
     *        scan_snow(npixel),scan_ice(npixel),scan_coast(npixel),
     *        scan_desert(npixel),scan_land(npixel),
     *        scan_process(npixel)

c     Array scalars.
      integer nc,debug,h_output
      logical day,visusd,snglnt,snow,ice,coast,desert,land,process

c ... Common statement for debug purposes
      common / bug / debug, h_output

c---------------------------------------------------------------------

c     Fill arrays.
 
      scan_confdnc(nc) = confdnc
      scan_visusd(nc) = visusd
      scan_snglnt(nc) = snglnt
      scan_snow(nc) = snow
      scan_ice(nc) = ice
      scan_coast(nc) = coast
      scan_desert(nc) = desert
      scan_land(nc) = land
      scan_process(nc) = process
      scan_day(nc) = day

c---------------------------------------------------------------------

      return
      end
